@@ -283,7 +283,7 @@ def _get_env_and_upload(s3_uploader, env, env_blacklist, env_file, log):
     key_value_list = _get_env_key_value_list(env, log, env_blacklist)
     try:
         # copy env to temporary file
-        with tempfile.NamedTemporaryFile() as dst:
+        with tempfile.NamedTemporaryFile(mode="w") as dst:
             dst.write("\n".join(key_value_list) + "\n")
             dst.flush()
             s3_uploader.put_file(dst.name, env_file)
